/**
 * CART
 * ==========
 */

var Cart = function() {
	this.items = [];
	this.total = 0;
};

/**
 * Get all cart items.
 */
Cart.prototype.showItems = function() {
	return this.items;
};

/**
 * Adds an item to the cart.
 *
 * @params {object} item -	Item to add to the cart.
 * @params {number} q    -	Number of items to add.
 * returns {Cart} 			this cart.
 */
Cart.prototype.addItem = function(item, q) {
	let items = this.items;
	q = parseInt(q, 10);
	if (items.length > 0) {
		for (let i = 0; i < items.length; i++) {
			if (items[i].item._id.toString() === item._id.toString()) {
				items[i].quantity += q;
				this.total += items[i].item.price * q;
				return this;
			}
		}
	}

	let itemObj = {};
	itemObj.item = item;
	itemObj.quantity = q;
	this.items.push(itemObj);
	this.total += (item.price * q);
	return this;
};

/**
 * Removes an item from the cart.
 *
 * @params {string} id -	ObjectId of item to remove.
 * returns {Cart} 			this cart.
 */
Cart.prototype.removeItem = function(id) {
	let items = this.items;
	if (items.length > 0) {
		for (let i = 0; i < items.length; i++) {
			if (items[i].item._id.toString() === id.toString()) {
				this.total -= items[i].item.price * items[i].quantity;
				items.splice(i, 1);
				return this;
			}
		}
	}
};

/**
 * Gets the cart total.
 * returns {number}		Total.
 */
Cart.prototype.getTotal = function() {
	return this.total;
};


module.exports = exports = {
	cart: Cart
}; 